# flake8: noqa: E501
TRANSLATION = {
    "new": '新的',
    "Create": '建立',
    "add": '增加',
    "Edit": '校对',
    "edit": '校对',
    "Save": '储存',
    "Remove": '删除',
    "Reload": '重启',
    "send": '发送',
    "select": '选择',
    "filters": '过滤',
    "apply": '应用',
    "Cancel": '取消',
    "field": '范围',
    "actions": '活动',
    "sublinks": '输入链接',
    "name": '种类',
    "type": '类型',
    "owner": '业主',
    "notes": '标记',
    "copy": '复制',
    "error": '错误',
    "home": '主要的',
    "login": '进入',
    "logout": '退出',
    "profile": '轮廓',
    "settings": '设置',
    "Settings": '设置',
    "version": '版本',
    "cache": '隐藏',
    "documentation": '文件',
    "request": '询问',
    "repository": '复位器',
    "app info": '信息',
    "status": '状态',
    "list is empty": '空白表格',
    "child instances": '输入对象',
    "enter value": '输入意义',
    "More info": '输入价值',
    "more info": '输入价值',
    "search by": '更详尽',
    'system': '范围查找',
    'users': '系统',
    'Is active': '活跃度',
    'Is staff': '减速装置',
    'Field "<b>{0}</b>" is empty.': '范围"<b>{0}</b>" 是空的',
    'Field "<b>{0}</b>" is required.': '范围"<b>{0}</b>" 必须完成',
    'Field "<b>{0}</b>" is too short.<br> Field length should not be shorter, than {1}.': '长度范围 "<b>{0}</b>" 太少.<br>长度范围应不少于{1}.',
    'Field "<b>{0}</b>" is too long. <br> Field length should not be longer, than {1}.': '长度单位"<b>{0}</b>" 太大<br>长度单位 应不大于{1}.',
    'Field "<b>{0}</b>" is too small.<br> Field should not be smaller, than {1}.': '取值范围 "<b>{0}</b>" 太少.<br> 取值范围应不少于 {1}.',
    'Field "<b>{0}</b>" is too big.<br> Field should not be bigger, than {1}.': '取值范围 "<b>{0}</b>" 太大.<br> 取值范围应不大于{1}.',
    '<b>{0} </b> value is not valid for <b>{1}</b> field.': '不能在 <b>{1}</b>取值为<b>{0}</b> .',
    '<b>"{0}"</b> field should be written in <b>"example@mail.com"</b> format.': '应在 <b>"example@mail.com"</b>.范围内完成<b>"{0}"</b>',
    'Child "<b>{0}</b>" instance was successfully added to parent list.': '子对象“ <b> {0} </ b>”已成功添加到母列表中.',
    'New "<b>{0}</b>" instance was successfully created.': '新对象“ <b> {0} </ b>”已成功创建.',
    '"<b>{0}</b>" {1} was successfully removed.': '"<b>{0}</b>" {1} 已成功删除."',
    'Changes in "<b>{0}</b>" {1} were successfully saved.': '对象变化{1}“ <b> {0} </ b>”的更改已成功保存.',
    'Action "<b>{0}</b>" was successfully executed on "<b>{1}</b>" instance.': '在对象“ <b> {1} </ b>”上成功启动了操作“ <b> {0} </ b>”。',
    'Some error occurred during adding of child "<b>{0}</b>" instance to parent list.<br> Error details: {1}': '将对象“ <b> {0} </ b>”添加到目级列表时发生错误。<br>更多详细信息：{1}',
    'Some error occurred during new "<b>{0}</b>" instance creation.<br> Error details: {1}': '创建新对象“ <b> {0} </ b>”时发生错误<br>更多详细信息：{1}',
    'Some error occurred during remove process of "<b>{0}</b>" {1}.<br> Error details: {2}': '删除{1}“ <b> {0} </ b>”时发生错误<br>更多详细信息：{2}',
    'Some error occurred during saving process of "<b>{0}</b>" {1}.<br> Error details: {2}': '保存{1}“ <b> {0} </ b>”时发生错误。<br>更多详细信息：{2}',
    'Some error occurred during "<b>{0}</b>" action execution on {1}.<br> Error details: {2}': '在{1}上执行操作“ <b> {0} </ b>”时发生错误<br>更多详细信息：{2}',
    'customize application styles': '自定义应用程序颜色样式',
    'skin': '主题',
    'skin settings': '主题设置',
    'active menu background': '活动菜单项的背景',
    'active menu color': '活动菜单项',
    'body background': '页面背景',
    'top navigation background': '顶部导航框的背景',
    'top navigation border': '顶部导航块的边框',
    'left sidebar background': '左侧边栏背景',
    'left sidebar border': '左侧的侧边栏',
    'customizer sidebar background': '侧边栏的背景',
    'breadcrumbs background': '面包屑背景',
    'buttons default background': '标准按钮背景',
    'buttons default text': '标准按钮背景',
    'buttons default border': '标准按钮边框',
    'buttons primary background': '主按钮背景',
    'buttons primary text': '主按钮文字',
    'buttons primary border': '主按钮边框',
    'buttons danger background': '背景危险按钮',
    'buttons danger text': '文字危险按钮',
    'buttons danger border': '边缘危险按钮',
    'buttons warning background': '背景提醒按钮',
    'buttons warning text': '警告按钮文字',
    'buttons warning border': '警告按钮边框',
    'links': '链接',
    'links hover': '悬停链接',
    'links revers': '链接暗色背景',
    'links hover revers': '悬停在黑暗背景上的链接',
    'text color': '文章',
    'ico default color': '标准图标颜色',
    'text header color': '标题',
    'background default color': '背景标准色',
    'card header background': '“卡片”部分顶部背景',
    'card body background': '“卡片”部分主题背景',
    'card footer background': '“卡片”部分底部背景',
    'card color': '插件中的文本“卡片”',
    'labels': '标签',
    'help content': '支持内容',
    'help text color': '支持文章',
    'table line hover bg color': '悬停表行背景',
    'table border color': '表格边框',
    'table line selected bg color': '所选表格行的背景',
    'background active color': '活动元素背景',
    'background passive color': '非活动元素背景',
    'text hover color': '悬停时的文字颜色',
    'boolean true color': '布尔值的颜色，值为“ true”',
    'boolean false color': '值为“ false”的布尔变量的颜色',
    'modal background color': '模态窗口背景',
    'api sections background color': 'api中的背景部分',
    'api sections border color': 'api中的边框部分',
    'code highlighting color 1': '代码突出显示-颜色1',
    'code highlighting color 2': '代码突出显示-颜色2',
    'code highlighting color 3': '代码突出显示-颜色3',
    'code highlighting color 4': '代码突出显示-颜色4',
    'code highlighting color 5': '代码突出显示-颜色5',
    'code highlighting color 6': '代码突出显示-颜色6',
    'code highlighting color 7': '代码突出显示-颜色7',
    'custom css': '自定义CSS',
    'reset skin settings to default': '恢复默认设置',
    'save skin': '储存主题',
    'Skin settings were successfully reset to default.': '主题设置已成功恢复为默认值',
    'Skin settings were successfully saved': '主题设置已成功保存',
    'actions on': '行动结束',
    'on item': '元素| 元素| 元素| 元素',
    'key': '要素',
    'value': '意义',
    'new owner': '新业主',
    'detail': '细节',
    'description': '描述',
    'id__not': '排除编号',
    'username': '使用者',
    'is active': '活跃度',
    'user': '使用者',
    'yes': '是',
    'no': '否',
    'is staff': '管理',
    'first_name': '名字',
    'last_name': '姓',
    'last name': '姓',
    'password': '密码',
    'Password': '密码',
    'Change password': '变换密码',
    'Change_password': '变换密码',
    'generate password': '形成密码',
    'repeat password': '重复密码',
    'Repeat password': '重复密码',
    'Old password': '旧密码',
    'New password': '新密码',
    'Confirm new password': '确认密码',
    'username__not': '排除用户名',
    'name__not': '排除名称',
    'kind': '类型',
    'mode': '制度',
    'options': '选项',
    'height': '高度',
    'width': '宽度',
    'information': '信息',
    'date': '日期',
    'file n selected': '未选择文件| 已选择1个文件| 已选择{n}个文件| 已选择{n}个文件',
    'image n selected': '未选择图像 已选择1张图片| 已选择{n}张图片| 已选择{n}张图片',
    'Ordering': '排列顺序',
    'is_active': '活跃度',
    'Username': '使用名',
    'first name': '名字',
    'First name': '名字',
    'Last name': '姓',
    'boolean value meaning status of user.': '指示用户状态的布尔值。',
    'users first name.': '用户名',
    'users last name.': '用户姓',
    'users e-mail value.': '用户邮箱',
    'which field to use when ordering the results.': '结果排序依据的字段',
    'a unique integer value (or comma separated list) identifying this instance.': '标识此对象的唯一数值（或用逗号分隔的序列）识别此对象',
    'a name string value (or comma separated list) of instance.': '对象名称-字符串值（或它们的顺序，用逗号分隔）',
    'page matching current url was not found': '找不到与指定网址匹配的页面',
    'sign in to start your session': '登录开始会议',
    'sign in': '进入',
    'sign up': '请注册',
    'forgot password': '忘记密码',
    'confirm password': '确认密码',
    'register': '注册',
    'fields with * is required': '标有*为必填项',
    'Forgotten your password? Enter your email address below, and we\'ll email instructions for setting a new one.': '忘记密码了吗？ 输入您的地址，我们将向您发送恢复指示',
    'reset my password': '问密码',
    'We\'ve emailed you instructions for setting your password, if an account exists with the email you entered. You should receive them shortly.': '我们已向您发送了一封电子邮件，其中包含有关重设密码的说明',
    'If you don\'t receive an email, please make sure you\'ve entered the address you registered with, and check your spam folder.': '如果您尚未收到电子邮件，请确认输入正确的地址并检查垃圾邮件文',
    'The password reset link was invalid, possibly because it has already been used. Please request a new password reset.': '无效的密码恢复链接，可能已被使用。 请再试一次。',
    'Please enter your new password twice so we can verify you typed it in correctly.': '请输入新密码',
    'change my password': '换密码',
    'Your password has been set.  You may go ahead and log in now.': '您的密码已成功设置。 您现在可以登录',
    'Please enter a correct %(username)s and password. Note that both fields may be case-sensitive.': '请输入正确的％（用户名）和密码。 注意，这些字段可能区分大小写',
    'or': '或者',
    'two-factor authentication code': '两因素授权码',
    'verify code': '确认密码',
    'Enter the code from the two-factor app on your mobile device. If you\'ve lost your device, you may enter one of your recovery codes.': '从您的移动设备上的两个应用程序中输入代码。 如果您丢失了设备，则可以输入恢复其中一个代码',
    'Invalid authentication code': '无效的授权码',
    'Scan the image with the two-factor authentication app on your phone. If you can’t use a barcode, enter this text code instead.': '使用手机上的两个身份验证应用程序扫描图像。 如果您不能使用条形码，请输入文本代码。',
    'Enter the six-digit code from the application': '从应用程序中输入六个字符的代码',
    'code': '代码',
    'recovery codes': '恢复代码',
    'Recovery codes are used to access your account in the event you cannot receive two-factor authentication codes.': '如果您无法获得两个身份验证码，则可以使用恢复码来访问您的帐户。',
    'Disabling Two-Factor Authentication (2FA) will decrease your account\'s security': '禁用两个身份验证会降低您帐户的安全性',
    'Enable': '打开',
    'Disable': '关闭',
    'Two factor authentication': '两个验证',
    'No {0} matches the given query.': '{0}没有一个与此请求匹配',
    'Password is not correct.': '密码不正确',
    'New passwords values are not equal.': '新密码值不相同',
    'This password is entirely numeric.': '该密码应使用完全数字',
    'Dark theme': '黑色主题',
    'Language': '语言',
    'unsupported image file format, expected ({0}), got {1}': '不支持的图像格式，支持（{0}），已收到{1}',
    'for some reason, this image file cannot be opened': '无法打开图像文件',
    'Invalid image {0}. Expected from {1} to {2}, got {3}': "{0}图片不正确。 预期从{1}到{2}，收到{3}",
    'imageValidationResolutionError': "必须至少为{min}且不超过{max}个像素",
    'Dark mode': '黑暗主题',


    # Проверить
    'Changes in settings are successfully saved. Please refresh the page.': '设置更改已成功保存。 请刷新页面。',
    'now': '眼下',
    'later': '之后',
    'i accept the ': '我接受 ',
    'terms of agreement': '协议条款',
    'Zoom': '飛漲',
    'Scale': '規模',
}
