# flake8: noqa: E501
TRANSLATION = {
    'new': 'Mới',
    'Create': 'tạo',
    'add': 'thêm',
    'Edit': 'chỉnh sửa',
    'edit': 'Chỉnh sửa',
    'Save': 'lưu',
    'Remove': 'xóa',
    'Reload': 'làm mới',
    'send': 'gửi',
    'select': 'chọn',
    'filters': 'bộ lọc',
    'apply': 'áp dụng',
    'Cancel': 'Hủy',
    'field': 'tường',
    'actions': 'thao tác',
    'sublinks': 'đường dẫn',
    'name': 'tên',
    'type': 'loại',
    'owner': 'chủ sở hữu',
    'notes': 'ghi chú',
    'copy': 'sao chép',
    'error': 'lỗi',
    'home': 'trang chủ',
    'login': 'đăng nhập',
    'logout': 'đăng xuất',
    'profile': 'hồ sơ',
    'settings': 'thiết lập',
    'Settings': 'Thiết lập',
    'version': 'phiên bản',
    'cache': 'bộ nhớ đệm',
    'documentation': 'tài liệu',
    'request': 'yêu cầu',
    'repository': 'kho thông tin',
    'app info': 'thông tin',
    'status': 'trạng thái',
    'list is empty': 'danh sách trống',
    'child instances': 'thêm các mục lồng',
    'enter value': 'nhập giá trị',
    'More info': 'thêm thông tin',
    'more info': 'thêm thông tin',
    'search by': 'tìm kiếm theo',
    'system': 'Hệ thống',
    'users': 'Người dùng',
    'Is active': 'Hoạt động',
    'Is staff': 'Người điều hành',
    'Field "<b>{0}</b>" is empty.': 'Trường "<b> {0} </b>" trống không',
    'Field "<b>{0}</b>" is required.': 'Trường "<b> {0} </b>"  bắt buộc.',
    'Field "<b>{0}</b>" is too short.<br> Field length should not be shorter, than {1}.': 'Độ dài của trường "<b> {0} </b>" quá ngắn. <br> Độ dài của trường không được nhỏ hơn {1}.',
    'Field "<b>{0}</b>" is too long. <br> Field length should not be longer, than {1}.': 'Độ dài của trường "<b> {0} </b>" quá dài. <br> Trường không được dài hơn {1}.',
    'Field "<b>{0}</b>" is too small.<br> Field should not be smaller, than {1}.': 'Giá trị của trường "<b> {0} </b>" quá nhỏ. <br> Giá trị của trường không được nhỏ hơn {1}.',
    'Field "<b>{0}</b>" is too big.<br> Field should not be bigger, than {1}.': 'Giá trị của trường "<b> {0} </b>" quá lớn. <br> Giá trị của trường không được lớn hơn {1}.',
    '<b>{0} </b> value is not valid for <b>{1}</b> field.': 'Giá trị <b> {0} </b> không hợp lệ cho trường <b> {1} </b>.',
    '<b>"{0}"</b> field should be written in <b>"example@mail.com"</b> format.': 'Trường <b> "{0}" </b> phải làm như <b> "example@mail.com" </b>.',
    'Child "<b>{0}</b>" instance was successfully added to parent list.': 'Đối tượng con "<b> {0} </b>" đã được thêm thành công vào danh sách mẹ.',
    'New "<b>{0}</b>" instance was successfully created.': 'Đối tượng mới "<b> {0} </b>" đã được tạo thành công.',
    '"<b>{0}</b>" {1} was successfully removed.': '"<b> {0} </b>" {1} đã được xóa thành công."',
    'Changes in "<b>{0}</b>" {1} were successfully saved.': 'Thay đổi đối tượng {1} "<b> {0} </ b>" đã được lưu thành công.',
    'Action "<b>{0}</b>" was successfully executed on "<b>{1}</b>" instance.': 'Thao tác "<b> {0} </b>" đã được thực hiện thành công trên đối tượng "<b> {1} </b>".',
    'Some error occurred during adding of child "<b>{0}</b>" instance to parent list.<br> Error details: {1}': 'Khi thêm đối tượng con "<b> {0} </b>" vào danh sách mẹ đã xảy ra lỗi <br> thêm chi tiết: {1}',
    'Some error occurred during new "<b>{0}</b>" instance creation.<br> Error details: {1}': 'Khi tạo đối tượng mới "<b> {0} </b>". đã xảy ra lỗi <br> biết thêm chi tiết: {1}',
    'Some error occurred during remove process of "<b>{0}</b>" {1}.<br> Error details: {2}': 'Khi xóa {1} "<b> {0} </b>". đã xảy ra lỗi <br> thêm chi tiết: {2}',
    'Some error occurred during saving process of "<b>{0}</b>" {1}.<br> Error details: {2}': 'Khi lưu {1} "<b> {0} </b>". đã xảy ra lỗi <br> thêm chi tiết: {2}',
    'Some error occurred during "<b>{0}</b>" action execution on {1}.<br> Error details: {2}': 'Khi chạy tác vụ "<b> {0} </b>" {1}.  đã xảy ra lỗi <br> thêm chi tiết: {2}',
    'customize application styles': 'thiết lập màu sắc của phần mềm',
    'skin': 'màu',
    'skin settings': 'сài đặt màu',
    'active menu background': 'màu mục menu hoạt động',
    'active menu color': 'mục menu hoạt động',
    'body background': 'phông nền của trang',
    'top navigation background': 'phông nền của thanh điều hướng',
    'top navigation border': 'phác thảo của thanh điều hướng',
    'left sidebar background': 'phông nền của menu',
    'left sidebar border': 'phác thảo của menu',
    'customizer sidebar background': 'phông nền của menu này',
    'breadcrumbs background': 'phông nền của menu chính',
    'buttons default background': 'phông nền của nút mặc định',
    'buttons default text': 'chữ của nút mặc định',
    'buttons default border': 'phác thảo của nút mặc định',
    'buttons primary background': 'phông nền của nút chính',
    'buttons primary text': 'chữ của nút chính',
    'buttons primary border': 'phác thảo của nút chính',
    'buttons danger background': 'phông nền của nút "danger"',
    'buttons danger text': 'chữ của nút "danger"',
    'buttons danger border': 'phác thảo của nút "danger"',
    'buttons warning background': 'phông nền của nút "warning"',
    'buttons warning text': 'chữ của nút "warning"',
    'buttons warning border': 'phác thảo của nút "warning"',
    'links': 'đường dẫn',
    'links hover': 'đường dẫn khi di chuột',
    'links revers': 'đường dẫn trên nền tối',
    'links hover revers': 'đường dẫn trên nền tối khi di chuột',
    'text color': 'văn bản',
    'ico default color': 'màu bình thường',
    'text header color': 'tiêu đề',
    'background default color': 'màu nền mặc định',
    'card header background': 'phông nền của phần "card" trên',
    'card body background': 'phông nền của phần "card" chính',
    'card footer background': 'phông nền của phần "card" dưới',
    'card color': 'chữ của phần "card"',
    'labels': 'nhãn',
    'help content': 'nội dung phụ',
    'help text color': 'văn bản phụ',
    'table line hover bg color': 'phông nền của bảng màn hình',
    'table border color': 'bảng phác thảo',
    'table line selected bg color': 'phông nền của bảng đánh dấu',
    'background active color': 'phông nền của yếu tố hoạt động',
    'background passive color': 'phông nền của yếu tố không hoạt động',
    'text hover color': 'màu văn bản khi di chuột',
    'boolean true color': 'màu của từ "true"',
    'boolean false color': 'màu của từ  "false"',
    'modal background color': 'màu thuộc tính Modal',
    'api sections background color': 'màu Api',
    'api sections border color': 'phông nền Api',
    'code highlighting color 1': 'đèn nền - màu 1',
    'code highlighting color 2': 'đèn nền - màu 2',
    'code highlighting color 3': 'đèn nền - màu 3',
    'code highlighting color 4': 'đèn nền - màu 4',
    'code highlighting color 5': 'đèn nền - màu 5',
    'code highlighting color 6': 'đèn nền - màu 6',
    'code highlighting color 7': 'đèn nền - màu 7',
    'custom css': 'css tùy chỉnh',
    'reset skin settings to default': 'về cài đặt mặc định',
    'save skin': 'lưu màu',
    'Skin settings were successfully reset to default.': 'Cài đặt đã trở lại tiêu chuẩn',
    'Skin settings were successfully saved': 'Cài đặt đã lưu thành công',
    'actions on': 'thao tác trên',
    'on item': 'thành phần',
    'key': 'Chìa khóa',
    'value': 'Giá trị',
    'new owner': 'Chủ sở hữu mới',
    'detail': 'Chi tiết',
    'description': 'Miêu tả',
    'username': 'Tên người dùng',
    'is active': 'Hoạt động',
    'user': 'Người dùng',
    'yes': 'Có',
    'no': 'Không',
    'is staff': 'Admin',
    'first name': 'Tên',
    'last name': 'Họ',
    'password': 'Mật khẩu',
    'Password': 'Mật khẩu',
    'Change password': 'Đổi mật khẩu',
    'Change_password': 'Đổi mật khẩu',
    'generate password': 'Viết mật khẩu',
    'repeat password': 'Lập lại mật khẩu',
    'Repeat password': 'Lập lại mật khẩu',
    'Old password': 'Mật khẩu cũ',
    'New password': 'Mật khẩu mới',
    'Confirm new password': 'Xác nhận mật khẩu mới',
    'kind': 'Loại',
    'mode': 'Chế độ',
    'options': 'Tùy chọn',
    'height': 'chiều cao',
    'width': 'chiều rộng',
    'information': 'Thông tin',
    'Dark mode': 'Chủ đề tối',
    'date': 'Ngày',
    'file n selected': 'File chưa được chọn',
    'image n selected': 'Hình ảnh chưa được chọn',
    'Ordering': 'Thứ tự phân loại',
    'is_active': 'Hoạt động',
    'Username': 'Tên đăng nhập',
    'First name': 'Tên',
    'Last name': 'Họ',
    'boolean value meaning status of user.': 'giá trị boolean cho biết trạng thái của người dùng.',
    'users first name.': 'Tên người dùng',
    'users last name.': 'Họ người dùng',
    'users e-mail value.': 'E-mail người dùng',
    'which field to use when ordering the results.': 'trường để sắp xếp kết quả.',
    'a unique integer value (or comma separated list) identifying this instance.': 'giá trị số duy nhất',
    'a name string value (or comma separated list) of instance.': 'tên đối tượng',
    'page matching current url was not found': 'trang web theo URL này không thể tìm được',
    'sign in to start your session': 'đăng nhập để bắt đầu',
    'sign in': 'đăng nhập',
    'sign up': 'đăng ký',
    'forgot password': 'quên mật khẩu',
    'confirm password': 'xác nhận mật khẩu',
    'register': 'đăng ký',
    'fields with * is required': 'các mục có dấu * là bắt buộc',
    'Forgotten your password? Enter your email address below, and we\'ll email instructions for setting a new one.': 'Quên mật khẩu? Nhập E-mail để nhận hướng dẫn khôi phục mật khẩu',
    'reset my password': 'Hủy mật khẩu',
    'We\'ve emailed you instructions for setting your password, if an account exists with the email you entered. You should receive them shortly.': 'Hướng dẫn hủy mật khẩu đã được gửi vào e-mail của bạn.',
    'If you don\'t receive an email, please make sure you\'ve entered the address you registered with, and check your spam folder.': '"Nếu bạn chưa nhận được thư, hãy kiểm tra lại địa chỉ e-mail và mục Spam."',
    'The password reset link was invalid, possibly because it has already been used. Please request a new password reset.': '"Đường dẫn không đúng, có thể đã được sử dụng. Xin hãy thử lại lần nữa."',
    'Please enter your new password twice so we can verify you typed it in correctly.': 'Nhập mật khẩu mới',
    'change my password': 'Thay đổi mật khẩu',
    'Your password has been set.  You may go ahead and log in now.': 'Thay đổi mật khẩu thành công. Hãy đăng nhập.',
    'Please enter a correct %(username)s and password. Note that both fields may be case-sensitive.': 'Vui lòng nhập chính xác% (tên người dùng) s và mật khẩu',
    'or': 'hoặc',
    'two-factor authentication code': 'hai bước xác thực (2FA)',
    'verify code': 'xác nhận mã',
    'Field <b>{0}</b>" is too short.<br> Field length should not be shorter, than {1}.': 'Độ dài của trường "<b> {0} </b>" quá ngắn. <br> Độ dài của trường không được nhỏ hơn {1}.',
    'Field <b>{0}</b>" is too long. <br> Field length should not be longer, than {1}.': 'Độ dài của trường "<b> {0} </b>" quá dài. <br> Trường không được dài hơn {1}.',
    'Field <b>{0}</b>" is too small.<br> Field should not be smaller, than {1}.': 'Giá trị của trường "<b> {0} </b>" quá nhỏ. <br> Giá trị của trường không được nhỏ hơn {1}.',
    'Field <b>{0}</b>" is too big.<br> Field should not be bigger, than {1}.': 'Giá trị của trường "<b> {0} </b>" quá lớn. <br> Giá trị của trường không được lớn hơn {1}.',
    '"<b>{0}</b> {1} was successfully removed."': '"""<b> {0} </b>"" {1} đã được xóa thành công."',
    'Enter the code from the two-factor app on your mobile device. If you\'ve lost your device, you may enter one of your recovery codes.': '"Nhập mã từ ứng dụng sử dụng hai bước xác thực trên thiết bị di động của bạn.Nếu bạn mất thiết bị của mình, bạn có thể nhập một trong các mã khôi phục."',
    'Invalid authentication code': 'Mã xác thực không hợp lệ',
    'Scan the image with the two-factor authentication app on your phone. If you can’t use a barcode, enter this text code instead.': '"Quét hình ảnh bằng ứng dụng xác thực hai bước trên điện thoại của bạn. Nếu bạn không thể quét hình ảnh, hãy nhập mã văn bản."',
    'Enter the six-digit code from the application': 'Điền mã xác thực từ ứng dụng',
    'code': 'Mã',
    'recovery codes': 'Mã khôi phục',
    'Recovery codes are used to access your account in the event you cannot receive two-factor authentication codes.': 'Mã khôi phục được sử dụng để truy cập vào tài khoản của bạn nếu bạn không thể nhận được mã xác thực hai bước.',
    'Disabling Two-Factor Authentication (2FA) will decrease your account\'s security': 'mã xác thực hai bước.',
    'Enable': 'Bật',
    'Disable': 'Tắt',
    'Two factor authentication': 'Xác thực hai bước (2FA)',
    'No {0} matches the given query.': 'Không tìm thấy',
    'Password is not correct.': 'Sai mật khẩu',
    'New passwords values are not equal.': 'Mật khẩu mới không chính xác',
    'This password is entirely numeric.': 'Mật khẩu này chỉ có chữ số.',
    'Dark theme': 'Màn hình tối',
    'Language': 'Ngôn ngữ',
    'unsupported image file format, expected ({0}), got {1}': 'Định dạng hình ảnh không được hỗ trợ, Được hỗ trợ ({0}), đã nhận {1}',
    'for some reason, this image file cannot be opened': 'Không thể mở file hình ảnh',
    'Invalid image {0}. Expected from {1} to {2}, got {3}': 'Hình ảnh {0} không chính xác. Dự kiến ​​từ {1} đến {2}, đã nhận {3}',
    'imageValidationResolutionError': 'Phải có ít nhất {min} và không nhiều hơn {max} pixel.',

    # Проверить
    'Changes in settings are successfully saved. Please refresh the page.': 'Các thay đổi trong cài đặt đã được lưu thành công. Vui lòng làm mới trang.',
    'now': 'hiện nay',
    'later': 'một lát sau',
    'i accept the ': 'Tôi chấp nhận ',
    'terms of agreement': 'các điều khoản của thỏa thuận',
    'Zoom': 'Thu phóng',
    'Scale': 'Tỉ lệ',
}
